@@ -64,6 +64,7 @@ function updatePlaceFromOSMObject(place, object) {
     }
     place.population = object.get_tag('population');
     place.website = object.get_tag('website');
+    place.email = object.get_tag('email');
     place.phone = object.get_tag('phone');
     place.wiki = object.get_tag('wikipedia');
     place.openingHours = object.get_tag('opening_hours');
@@ -71,6 +72,7 @@ function updatePlaceFromOSMObject(place, object) {
     place.toilets = object.get_tag('toilets');
     place.internetAccess = object.get_tag('internet_access');
     place.religion = object.get_tag('religion');
+    place.takeaway = object.get_tag('takeaway');
 
     let altitude = object.get_tag('ele');
 
